==> haskell-monad-par-extras-0.3.3-315.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-Lo0LacZPPum6MnfInbJ63S
key:                  monad-par-extras-0.3.3-Lo0LacZPPum6MnfInbJ63S
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  f05250e55d3bc47b6e893ab373775a21
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-par-extras-0.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par-extras
hs-libraries:         HSmonad-par-extras-0.3.3-Lo0LacZPPum6MnfInbJ63S
depends:
    abstract-par-0.3.3-1dic12KP6HG1xgohiLvlv6 base-4.18.2.1
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK deepseq-1.4.8.1 mtl-2.3.1
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-316-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-Gn7JEqsnOJfBQYUOE0OTOI
key:                  monad-par-extras-0.3.3-Gn7JEqsnOJfBQYUOE0OTOI
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  ffd680bf6ffde90565cd25eedff1f82d
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-par-extras-0.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par-extras
hs-libraries:         HSmonad-par-extras-0.3.3-Gn7JEqsnOJfBQYUOE0OTOI
depends:
    abstract-par-0.3.3-1dic12KP6HG1xgohiLvlv6 base-4.18.2.1
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK deepseq-1.4.8.1 mtl-2.3.1
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
